EmPOWER Core Library
====================

### What is the EmPOWER Core Library?
This is a core library for the 5G-EmPOWER Runtime and a few other projects. It
provides some common building blocks for writing network controller and service
orchestrators.

### License
Code is released under the Apache License, Version 2.0.
